@@ -22,10 +22,10 @@
 # OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 # SUCH DAMAGE.
 #
-# $Id: scgi_base.py 2306 2007-01-02 22:15:53Z asaddi $
+# $Id$
 
 __author__ = 'Allan Saddi <allan@saddi.com>'
-__version__ = '$Revision: 2306 $'
+__version__ = '$Revision$'
 
 import sys
 import logging
@@ -472,9 +472,16 @@ class BaseSCGIServer(object):
 
     def _sanitizeEnv(self, environ):
         """Fill-in/deduce missing values in environ."""
+        reqUri = None
+        if environ.has_key('REQUEST_URI'):
+            reqUri = environ['REQUEST_URI'].split('?', 1)
+
         # Ensure QUERY_STRING exists
-        if not environ.has_key('QUERY_STRING'):
-            environ['QUERY_STRING'] = ''
+        if not environ.has_key('QUERY_STRING') or not environ['QUERY_STRING']:
+            if reqUri is not None and len(reqUri) > 1:
+                environ['QUERY_STRING'] = reqUri[1]
+            else:
+                environ['QUERY_STRING'] = ''
 
         # Check WSGI_SCRIPT_NAME
         scriptName = environ.get('WSGI_SCRIPT_NAME')
@@ -495,8 +502,11 @@ class BaseSCGIServer(object):
             # Pull SCRIPT_NAME/PATH_INFO from environment, with empty defaults
             if not environ.has_key('SCRIPT_NAME'):
                 environ['SCRIPT_INFO'] = ''
-            if not environ.has_key('PATH_INFO'):
-                environ['PATH_INFO'] = ''
+            if not environ.has_key('PATH_INFO') or not environ['PATH_INFO']:
+                if reqUri is not None:
+                    environ['PATH_INFO'] = reqUri[0]
+                else:
+                    environ['PATH_INFO'] = ''
         else:
             # Configured scriptName
             warnings.warn('Configured SCRIPT_NAME is deprecated\n'
